$describe
$describe_separators

Target Server
-------------

$target_url

Request
-------
::

  $request

Parameters
----------

::

  $params

Response
--------

::

  Status:       $status_code
  Content-Type: $response_content_type
  Response:
  $response_body
